#ifndef THINGS_THINGINSTANCE_H
#define THINGS_THINGINSTANCE_H
///
/// @file 
/// @version $Id$
/// @date $Date$
///

#include "ThingInstanceBase.h"
#include "ThingSequenceNumber.h"
#include "ThingIdentifier.h"

namespace Things
{

///
/// @brief
/// Describes a unique instance of a Thing.
/// 
class ThingInstance: public ThingInstanceBase
{
public:
   /// @name House-keeping
   /// @{

   ThingInstance();

   virtual ~ThingInstance();

   /// @}
public:
   /// @name Mutators
   /// @{

   ///
   /// @brief
   /// Virtual method to apply the rule.
   ///
   /// The default implementation delegates to the applyThing method
   /// of the class derived from Thing pointed to by this->getThing().
   ///
   virtual void applyThing();
   
   ///
   /// @brief
   /// Assign a sequence number when adding a rule to a CompositeThing.
   ///
   /// @post
   /// @code this->getThingSequenceNumber() == sequenceNumber_ @endcode
   ///
   virtual void setThingSequenceNumber(ThingSequenceNumber sequenceNumber_);
  
   /// @}
private:
   /// @name State
   /// @{

   /// @}
}; //endclass ThingInstance

} //end namespace

#endif
